@@ -1,5 +1,9 @@
 #!/usr/bin/env python
-def epj2d (epj):
+from __future__ import absolute_import, division, print_function
+
+__all__ = ["epj2d"]
+
+def epj2d(epj):
     """
     Converts Julian epoch to Modified Julian Date.
     
@@ -21,7 +25,7 @@ def epj2d (epj):
 
 if __name__ == "__main__":
     import RO.MathUtil
-    print "testing epj2d"
+    print("testing epj2d")
     # testData is a list of duples consisting of:
     # - input data
     # - the expected output
@@ -35,6 +39,6 @@ if __name__ == "__main__":
     for testInput, expectedOutput in testData:
         actualOutput = epj2d(testInput)
         if 0 != RO.MathUtil.compareFloats(actualOutput, expectedOutput, rtol=1e-15):
-            print "failed on input:", testInput
-            print "expected output:", expectedOutput
-            print "actual output  :", actualOutput
+            print("failed on input:", testInput)
+            print("expected output:", expectedOutput)
+            print("actual output  :", actualOutput)
