@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+from __future__ import division, print_function
 """Code to run scripts that can wait for various things without messing up the main event loop
 (and thus starving the rest of your program).
 
@@ -84,6 +85,8 @@ History:
 2014-04-29 ROwen    Bug fix: pause followed by resume lost the value returned by whatever was being paused.
 2014-07-21 ROwen    Added waitPause and waitSec.
 """
+__all__ = ["ScriptError", "ScriptRunner"]
+
 import sys
 import threading
 import Queue
@@ -280,9 +283,9 @@ class ScriptRunner(RO.AddCallback.BaseMixin):
         if not self.debug:
             return
         try:
-            print msgStr
+            print(msgStr)
         except (TypeError, ValueError):
-            print repr(msgStr)
+            print(repr(msgStr))
 
     def getFullState(self):
         """Returns the current state as a tuple:
@@ -462,7 +465,7 @@ class ScriptRunner(RO.AddCallback.BaseMixin):
             self._statusBar.setMsg(msg, severity)
             self.debugPrint(msg)
         else:
-            print msg
+            print(msg)
     
     def startCmd(self,
         actor="",
@@ -777,7 +780,7 @@ class ScriptRunner(RO.AddCallback.BaseMixin):
             
             self._printState("_continue: before iteration")
             self._state = 0
-            possIter = self._iterStack[-1].next()
+            possIter = next(self._iterStack[-1])
             if hasattr(possIter, "next"):
                 self._iterStack.append(possIter)
                 self._iterID = self._getNextID(addLevel = True)
@@ -800,9 +803,9 @@ class ScriptRunner(RO.AddCallback.BaseMixin):
         except SystemExit:
             self.__del__()
             sys.exit(0)
-        except ScriptError, e:
+        except ScriptError as e:
             self._setState(Failed, RO.StringUtil.strFromException(e))
-        except Exception, e:
+        except Exception as e:
             traceback.print_exc(file=sys.stderr)
             self._printFullState()
             self._setState(Failed, RO.StringUtil.strFromException(e))
@@ -812,8 +815,8 @@ class ScriptRunner(RO.AddCallback.BaseMixin):
         Ignored unless _DebugState or self.debug true.
         """
         if _DebugState:
-            print "Script %s: %s: state=%s, iterID=%s, waiting=%s, iterStack depth=%s" % \
-                (self.name, prefix, self._state, self._iterID, self._waiting, len(self._iterStack))
+            print("Script %s: %s: state=%s, iterID=%s, waiting=%s, iterStack depth=%s" % \
+                (self.name, prefix, self._state, self._iterID, self._waiting, len(self._iterStack)))
     
     def _printFullState(self):
         """Print the full state to stderr
@@ -835,7 +838,7 @@ class ScriptRunner(RO.AddCallback.BaseMixin):
         if self._cmdStatusBar:
             self._cmdStatusBar.setMsg(msg, severity)
         else:
-            print msg
+            print(msg)
     
     def __del__(self, evt=None):
         """Called just before the object is deleted.
@@ -863,7 +866,7 @@ class ScriptRunner(RO.AddCallback.BaseMixin):
                 self._reason = "keyboard interrupt"
             except SystemExit:
                 raise
-            except Exception, e:
+            except Exception as e:
                 self._state = Failed
                 self._reason = "endFunc failed: %s" % (RO.StringUtil.strFromException(e),)
                 traceback.print_exc(file=sys.stderr)
@@ -972,7 +975,7 @@ class _WaitBase(object):
         except ValueError:
             raise RuntimeError("Cancel function missing; did you forgot the 'yield' when calling a ScriptRunner method?")
         if self.scriptRunner.debug and val != None:
-            print "wait returns %r" % (val,)
+            print("wait returns %r" % (val,))
         self.scriptRunner._continue(self._iterID, val)
 
 
@@ -1108,7 +1111,7 @@ class _WaitKeyVar(_WaitBase):
                 argList.append("defVal=%r" % (defVal,))
             if waitNext:
                 argList.append("waitNext=%r" % (waitNext,))
-            print "waitKeyVar(%s)" % ", ".join(argList)
+            print("waitKeyVar(%s)" % ", ".join(argList))
 
             # prevent the call from failing by using None instead of Exception
             if self.defVal == Exception:
@@ -1204,11 +1207,11 @@ if __name__ == "__main__":
 
     def initFunc(sr):
         global scriptList
-        print "%s init function called" % (sr,)
+        print("%s init function called" % (sr,))
         scriptList.append(sr)
 
     def endFunc(sr):
-        print "%s end function called" % (sr,)
+        print("%s end function called" % (sr,))
     
     def script(sr):
         def threadFunc(nSec):
